@@ -147,7 +147,20 @@ def add_disulfide_interactions(
     Find all disulfide interactions between CYS residues.
 
     Criteria: sulfur atom pairs are within 2.2A of each other.
+
+    :param G: networkx protein graph
+    :type G: nx.Graph
+    :param rgroup_df: pd.DataFrame containing rgroup data, defaults to None, which retrieves the df from the provided nx graph.
+    :type rgroup_df: pd.DataFrame, optional
     """
+    # Check for existence of at least two Cysteine residues
+    residues = [d["residue_name"] for _, d in G.nodes(data=True)]
+    if residues.count("CYS") < 2:
+        log.debug(
+            f"{residues.count('CYS')} CYS residues found. Cannot add disulfide interactions with fewer than two CYS residues."
+        )
+        return
+
     if rgroup_df is None:
         rgroup_df = G.graph["rgroup_df"]
     disulfide_df = filter_dataframe(
@@ -253,9 +266,6 @@ def add_aromatic_interactions(
         get_interacting_atoms), as they do not return centroid atom
         euclidean coordinates.
     """
-    if pdb_df is None:
-        pdb_df = G.graph["pdb_df"]
-
     dfs = []
     for resi in AROMATIC_RESIS:
         resi_rings_df = get_ring_atoms(pdb_df, resi)
@@ -274,10 +284,10 @@ def add_aromatic_interactions(
 
     interacting_resis = [
         (distmat.index[r], distmat.index[c])
-        for i, (r, c) in enumerate(zip(indices[0], indices[1]))
+        for r, c in zip(indices[0], indices[1])
     ]
 
-    for i, (n1, n2) in enumerate(interacting_resis):
+    for n1, n2 in interacting_resis:
         assert G.nodes[n1]["residue_name"] in AROMATIC_RESIS
         assert G.nodes[n2]["residue_name"] in AROMATIC_RESIS
         if G.has_edge(n1, n2):
@@ -623,6 +633,7 @@ def add_interacting_resis(
     resi2 = dataframe.loc[interacting_atoms[1]]["node_id"].values
 
     interacting_resis = set(list(zip(resi1, resi2)))
+    log.info(f"Found {len(interacting_resis)} {k} interactions.")
     for i1, i2 in interacting_resis:
         if i1 != i2:
             if G.has_edge(i1, i2):
